From 7ea89afa119615e547323a7a482ea7fef8e67029 Mon Sep 17 00:00:00 2001
From: Timothy Pearson <kb9vqf@pearsoncomputing.net>
Date: Mon, 19 Dec 2011 11:59:52 -0600
Subject: Remove additional unneeded tq method conversions

---
 khexedit/bitswapwidget.cc                     |  2 +-
 khexedit/dialog.cc                            |  4 ++--
 khexedit/exportdialog.cc                      |  6 ++---
 khexedit/fileinfodialog.cc                    |  4 ++--
 khexedit/hexbuffer.cc                         | 34 +++++++++++++--------------
 khexedit/hexeditorwidget.cc                   | 12 +++++-----
 khexedit/hexmanagerwidget.cc                  |  2 +-
 khexedit/hextoolwidget.cc                     |  2 +-
 khexedit/hexviewwidget.cc                     | 16 ++++++-------
 khexedit/lib/codecs/kbinarybytecodec.cpp      |  4 ++--
 khexedit/lib/codecs/kbytecodec.cpp            |  4 ++--
 khexedit/lib/codecs/kdecimalbytecodec.cpp     | 12 +++++-----
 khexedit/lib/codecs/khexadecimalbytecodec.cpp |  8 +++----
 khexedit/lib/codecs/koctalbytecodec.cpp       | 12 +++++-----
 khexedit/lib/kbufferdrag.cpp                  |  2 +-
 khexedit/lib/kbufferranges.h                  |  2 +-
 khexedit/lib/kbytesedit.h                     |  4 ++--
 khexedit/lib/kcolumnsview.cpp                 |  4 ++--
 khexedit/lib/kcursor.h                        |  2 +-
 khexedit/lib/kfixedsizebuffer.cpp             |  6 ++---
 khexedit/lib/khexedit.cpp                     | 10 ++++----
 khexedit/lib/kplainbuffer.cpp                 |  4 ++--
 khexedit/optiondialog.cc                      |  6 ++---
 khexedit/parts/kbytesedit/kbyteseditwidget.h  |  2 +-
 khexedit/statusbarprogress.cc                 | 10 ++++----
 khexedit/stringdialog.cc                      |  4 ++--
 khexedit/toplevel.cc                          | 12 +++++-----
 khexedit/toplevel.h                           |  2 +-
 28 files changed, 96 insertions(+), 96 deletions(-)

(limited to 'khexedit')

diff --git a/khexedit/bitswapwidget.cc b/khexedit/bitswapwidget.cc
index 6f79cad..77a4f16 100644
--- a/khexedit/bitswapwidget.cc
+++ b/khexedit/bitswapwidget.cc
@@ -132,7 +132,7 @@ void CDigitLabel::drawContents( TQPainter *p )
 
   TQString text;
   text.setNum( mDigit );
-  p->drawText( 0, 0, cr.width(), cr.height(), tqalignment(), text );
+  p->drawText( 0, 0, cr.width(), cr.height(), alignment(), text );
 
   
 
diff --git a/khexedit/dialog.cc b/khexedit/dialog.cc
index 404e402..1ce9636 100644
--- a/khexedit/dialog.cc
+++ b/khexedit/dialog.cc
@@ -1237,7 +1237,7 @@ void centerDialog( TQWidget *widget, TQWidget *centerParent )
   }
 
   TQPoint point = centerParent->mapToGlobal( TQPoint(0,0) );
-  TQRect pos    = centerParent->tqgeometry();
+  TQRect pos    = centerParent->geometry();
 
   widget->setGeometry( point.x() + pos.width()/2  - widget->width()/2,
 		       point.y() + pos.height()/2 - widget->height()/2,
@@ -1253,7 +1253,7 @@ void centerDialogBottom( TQWidget *widget, TQWidget *centerParent )
   }
 
   TQPoint point = centerParent->mapToGlobal( TQPoint(0,0) );
-  TQRect pos    = centerParent->tqgeometry();
+  TQRect pos    = centerParent->geometry();
 
   widget->setGeometry( point.x() + pos.width()/2  - widget->width()/2,
 		       point.y() + pos.height() - widget->height(),
diff --git a/khexedit/exportdialog.cc b/khexedit/exportdialog.cc
index 63b74c8..612c245 100644
--- a/khexedit/exportdialog.cc
+++ b/khexedit/exportdialog.cc
@@ -673,14 +673,14 @@ bool CExportDialog::verifyPackage( const TQString &path )
       }
 
       const TQString prefix = mHtml.prefixInput->text();
-      TQString f1 = TQString("%1%2.html").tqarg(prefix).tqarg("00000000");
-      TQString f2 = TQString("%1%2.html").tqarg(prefix).tqarg("99999999");
+      TQString f1 = TQString("%1%2.html").arg(prefix).arg("00000000");
+      TQString f2 = TQString("%1%2.html").arg(prefix).arg("99999999");
 
       TQString msg = i18n( ""
         "You have specified an existing folder.\n"
 	"If you continue, any existing file in the range "
 	"\"%1\" to \"%2\" can be lost.\n"
-	"Continue?").tqarg(f1).tqarg(f2);
+	"Continue?").arg(f1).arg(f2);
       int reply = KMessageBox::warningContinueCancel( this, msg, title );
       if( reply != KMessageBox::Continue )
       {
diff --git a/khexedit/fileinfodialog.cc b/khexedit/fileinfodialog.cc
index 957f1d7..a619846 100644
--- a/khexedit/fileinfodialog.cc
+++ b/khexedit/fileinfodialog.cc
@@ -239,13 +239,13 @@ void CFileInfoDialog::setStatistics( SStatisticControl &sc )
     o.sprintf("%03o", i );
     b.sprintf("%s", printBin(i) );
 
-    n = TQString("%1").tqarg( sc.occurrence[i], pre );
+    n = TQString("%1").arg( sc.occurrence[i], pre );
     if( sc.documentSize == 0 )
       p = "0.00";
     else
     {
       double val = 100.0*((double)sc.occurrence[i]/(double)sc.documentSize);
-      p = TQString("%1").tqarg( val, 6, 'f', 2 );
+      p = TQString("%1").arg( val, 6, 'f', 2 );
     }
 
     const TQChar _i((char)i);
diff --git a/khexedit/hexbuffer.cc b/khexedit/hexbuffer.cc
index dc3f167..746b00e 100644
--- a/khexedit/hexbuffer.cc
+++ b/khexedit/hexbuffer.cc
@@ -447,8 +447,8 @@ TQString SExportCArray::variableName( uint range ) const
   uint es = elementSize();
   uint numElement = range / es + ((range % es) ? 1 : 0);
 
-  return( TQString("%1 %2[%2]").tqarg(typeString[elementType]).
-	  tqarg(arrayName).tqarg(numElement) );
+  return( TQString("%1 %2[%2]").arg(typeString[elementType]).
+	  arg(arrayName).arg(numElement) );
 }
 
 
@@ -676,7 +676,7 @@ bool CHexBuffer::toggleEditor( void )
       edit_secondary : edit_primary;
   }
 
-  setEditMode( mEditMode ); // Sets the cursor tqshapes as well
+  setEditMode( mEditMode ); // Sets the cursor shapes as well
 
   if( changed == true )
   {
@@ -952,7 +952,7 @@ int CHexBuffer::writeFile( TQFile &file, CProgress &p )
 
 int CHexBuffer::readFile( TQFile &file, const TQString &url, CProgress &p )
 {
-  if( tqresize( file.size() + 100 ) == false )
+  if( resize( file.size() + 100 ) == false )
   {
     p.finish();
     return( Err_NoMemory );
@@ -1064,7 +1064,7 @@ int CHexBuffer::insertFile( TQFile &file, CProgress &p )
 
 int CHexBuffer::newFile( const TQString &url )
 {
-  if( tqresize( 100 ) == 0 )
+  if( resize( 100 ) == 0 )
   {
     return( Err_NoMemory );
   }
@@ -1923,8 +1923,8 @@ void CHexBuffer::drawHeader( TQPainter &paint, int sx, int width, int y,
     else if( header.pos[i] == SPageHeader::PageNumber )
     {
       msg = i18n("Page %1 of %2")
-        .tqarg(KGlobal::locale()->formatNumber(position.curPage, 0))
-        .tqarg(KGlobal::locale()->formatNumber(position.maxPage, 0));
+        .arg(KGlobal::locale()->formatNumber(position.curPage, 0))
+        .arg(KGlobal::locale()->formatNumber(position.maxPage, 0));
     }
     else if( header.pos[i] == SPageHeader::FileName )
     {
@@ -2091,7 +2091,7 @@ void CHexBuffer::drawCursor( TQPainter &paint, uint line, int startx,
   }
 
   //
-  // Draw the cursor tqshape
+  // Draw the cursor shape
   //
   bool transparent = false;
   if( mActiveEditor == edit_primary )
@@ -2116,7 +2116,7 @@ void CHexBuffer::drawCursor( TQPainter &paint, uint line, int startx,
 	  paint.drawLine( center-2, mFontHeight-1, center+2, mFontHeight-1 );
 	}
       }
-      else // Solid block tqshape
+      else // Solid block shape
       {
 	paint.fillRect( c.x1 - startx, 0, mUnitWidth, mFontHeight, cbg );
 	useFg = true;
@@ -2209,7 +2209,7 @@ void CHexBuffer::drawCursor( TQPainter &paint, uint line, int startx,
   }
 
   //
-  // Draw the cursor tqshape
+  // Draw the cursor shape
   //
   transparent = false;
   if( mActiveEditor == edit_secondary )
@@ -2822,16 +2822,16 @@ int CHexBuffer::exportHtml( const SExportHtml &ex, CProgress &p )
   for( uint i=0; i < numFiles; i++ )
   {
     name.sprintf( "%08d.html", i+1 );
-    fileNames.append( TQString("%1/%2%3").tqarg(ex.package).tqarg(ex.prefix).
+    fileNames.append( TQString("%1/%2%3").arg(ex.package).arg(ex.prefix).
 		      arg(name));
   }
   name.sprintf( "%08d.html", 0 );
-  TQString tocName =TQString("%1/%2%3").tqarg(ex.package).tqarg(ex.prefix).tqarg(name);
+  TQString tocName =TQString("%1/%2%3").arg(ex.package).arg(ex.prefix).arg(name);
 
   TQString linkName;
   if( ex.symLink == true )
   {
-    linkName = TQString("%1/%2").tqarg(ex.package).tqarg("index.html");
+    linkName = TQString("%1/%2").arg(ex.package).arg("index.html");
   }
 
   while( remaining  > 0 )
@@ -2849,7 +2849,7 @@ int CHexBuffer::exportHtml( const SExportHtml &ex, CProgress &p )
 
     THIS_FPTR(printOffset)( mPrintBuf, (startLine-1)*mLayout.lineSize );
     mPrintBuf[mOffsetSize]=0;
-    offset += TQString(" %1 [%2]").tqarg(i18n("to")).tqarg(mPrintBuf);
+    offset += TQString(" %1 [%2]").arg(i18n("to")).arg(mPrintBuf);
     offsets.append(offset);
 
     if( p.expired() == true )
@@ -2981,7 +2981,7 @@ int CHexBuffer::copyText( TQByteArray &array, const SExportRange &range,
 
   uint bytePerLine = mOffsetSize + 1 + (mNumCell + 2)*mLayout.lineSize + 1;
   uint size = (stopLine - startLine + 1)*bytePerLine;
-  if( array.tqresize( size+1 ) == false )
+  if( array.resize( size+1 ) == false )
   {
     return( Err_NoMemory );
   }
@@ -3021,7 +3021,7 @@ int CHexBuffer::copySelectedData( TQByteArray &array )
   }
 
   uint size = stop - start;
-  if( array.tqresize( size ) == false )
+  if( array.resize( size ) == false )
   {
     return( Err_NoMemory );
   }
@@ -4829,7 +4829,7 @@ void CHexBuffer::printHtmlCaption( TQTextStream &os, uint captionType,
     break;
 
     case 3:
-      caption = i18n("Page %1 of %2").tqarg(curPage).tqarg(numPage);
+      caption = i18n("Page %1 of %2").arg(curPage).arg(numPage);
     break;
   }
 
diff --git a/khexedit/hexeditorwidget.cc b/khexedit/hexeditorwidget.cc
index 5b255d8..c0ce4f6 100644
--- a/khexedit/hexeditorwidget.cc
+++ b/khexedit/hexeditorwidget.cc
@@ -580,7 +580,7 @@ void CHexEditorWidget::newFile( void )
     return;
   }
 
-  TQString url = i18n("Untitled %1").tqarg( mUntitledCount );
+  TQString url = i18n("Untitled %1").arg( mUntitledCount );
 
   //
   // If the url is already present in the document list (should not happen),
@@ -1978,7 +1978,7 @@ int CHexEditorWidget::readURL( const KURL &url, bool insert )
   //
   if( !url.isValid() )
   {
-    TQString msg = i18n("Malformed URL\n%1").tqarg( url.url() );
+    TQString msg = i18n("Malformed URL\n%1").arg( url.url() );
     KMessageBox::sorry( topLevelWidget(), msg, i18n("Read URL") );
     return( Err_IllegalArgument );
   }
@@ -2049,21 +2049,21 @@ bool CHexEditorWidget::readFile( const TQString &diskPath, const TQString &url,
   TQFileInfo info( diskPath );
   if( info.exists() == false )
   {
-    const TQString msg = i18n("The specified file does not exist.\n%1").tqarg( diskPath );
+    const TQString msg = i18n("The specified file does not exist.\n%1").arg( diskPath );
     KMessageBox::sorry( topLevelWidget(), msg, i18n("Read") );
     return( false );
   }
 
   if( info.isDir() == true )
   {
-    const TQString msg = i18n("You have specified a folder.\n%1").tqarg( diskPath );
+    const TQString msg = i18n("You have specified a folder.\n%1").arg( diskPath );
     KMessageBox::sorry( topLevelWidget(), msg, i18n("Read") );
     return( false );
   }
 
   if( info.isReadable() == false )
   {
-    const TQString msg = i18n("You do not have read permission to this file.\n%1").tqarg( diskPath );
+    const TQString msg = i18n("You do not have read permission to this file.\n%1").arg( diskPath );
     KMessageBox::sorry( topLevelWidget(), msg, i18n("Read") );
     return( false );
   }
@@ -2071,7 +2071,7 @@ bool CHexEditorWidget::readFile( const TQString &diskPath, const TQString &url,
   TQFile file( diskPath );
   if( file.open( IO_ReadOnly | IO_Raw ) == false )
   {
-    const TQString msg = i18n("An error occurred while trying to open the file.\n%1").tqarg( diskPath );
+    const TQString msg = i18n("An error occurred while trying to open the file.\n%1").arg( diskPath );
     KMessageBox::sorry( topLevelWidget(), msg, i18n("Read") );
     return( false );
   }
diff --git a/khexedit/hexmanagerwidget.cc b/khexedit/hexmanagerwidget.cc
index e5c5da6..2413f6b 100644
--- a/khexedit/hexmanagerwidget.cc
+++ b/khexedit/hexmanagerwidget.cc
@@ -126,7 +126,7 @@ void CHexManagerWidget::setConversionVisibility( EConversionPosition position )
   else if( mConversionPosition == Float )
   {
     TQPoint point = mapToGlobal( TQPoint(0,0) );
-    TQRect  rect  = tqgeometry();
+    TQRect  rect  = geometry();
     TQPoint p;
 
     p.setX(point.x() + rect.width()/2 - mConverter->minimumSize().width()/2);
diff --git a/khexedit/hextoolwidget.cc b/khexedit/hextoolwidget.cc
index a2c0cd9..b5e918e 100644
--- a/khexedit/hextoolwidget.cc
+++ b/khexedit/hextoolwidget.cc
@@ -258,7 +258,7 @@ void CHexToolWidget::cursorChanged( SCursorState &state )
     // checking for system endianess, using the compiler for the byte interpretation and cutting bloaded code
     // TODO: add PDP endianess
     void *P8Bit, *P16Bit, *P32Bit, *P64Bit;
-    // ensure strict tqalignment for double as needed on some architectures (e.g. PA-RISC)
+    // ensure strict alignment for double as needed on some architectures (e.g. PA-RISC)
     typedef union { unsigned char b[8]; double d; } aligned_t;
     aligned_t Data;
     if(
diff --git a/khexedit/lib/codecs/kbinarybytecodec.cpp b/khexedit/lib/codecs/kbinarybytecodec.cpp
index fc9fe8d..a49a460 100644
--- a/khexedit/lib/codecs/kbinarybytecodec.cpp
+++ b/khexedit/lib/codecs/kbinarybytecodec.cpp
@@ -24,7 +24,7 @@ using namespace KHE;
 void KBinaryByteCodec::encode( TQString &Digits, unsigned int Pos, const unsigned char Char ) const
 {
   for( unsigned char M=1<<7; M>0; M>>=1 )
-    Digits.tqat(Pos++) = (Char & M) ? '1' : '0';
+    Digits.at(Pos++) = (Char & M) ? '1' : '0';
 }
 
 void KBinaryByteCodec::encodeShort( TQString &Digits, unsigned int Pos, unsigned char Char ) const
@@ -36,7 +36,7 @@ void KBinaryByteCodec::encodeShort( TQString &Digits, unsigned int Pos, unsigned
       break;
   // now set the
   for( ; M>0; M>>=1 )
-    Digits.tqat(Pos++) = (Char & M) ? '1' : '0';
+    Digits.at(Pos++) = (Char & M) ? '1' : '0';
 }
 
 
diff --git a/khexedit/lib/codecs/kbytecodec.cpp b/khexedit/lib/codecs/kbytecodec.cpp
index 900055e..f4847ba 100644
--- a/khexedit/lib/codecs/kbytecodec.cpp
+++ b/khexedit/lib/codecs/kbytecodec.cpp
@@ -40,7 +40,7 @@ KByteCodec *KByteCodec::createCodec( KCoding C )
 
 unsigned int KByteCodec::decode( unsigned char *Char, const TQString &Digits, uint Pos ) const
 {
-  //kdDebug() << TQString("KByteCodec::decode(%1,%2)").tqarg(Digits).tqarg(Pos) << endl;
+  //kdDebug() << TQString("KByteCodec::decode(%1,%2)").arg(Digits).arg(Pos) << endl;
   const uint P = Pos;
 
   // remove leading 0s
@@ -50,7 +50,7 @@ unsigned int KByteCodec::decode( unsigned char *Char, const TQString &Digits, ui
   unsigned int d = encodingWidth();
   do
   {
-    if( !appendDigit(&C,Digits.tqat(Pos)) )
+    if( !appendDigit(&C,Digits.at(Pos)) )
       break;
 
     ++Pos;
diff --git a/khexedit/lib/codecs/kdecimalbytecodec.cpp b/khexedit/lib/codecs/kdecimalbytecodec.cpp
index 065eb81..c556875 100644
--- a/khexedit/lib/codecs/kdecimalbytecodec.cpp
+++ b/khexedit/lib/codecs/kdecimalbytecodec.cpp
@@ -24,12 +24,12 @@ using namespace KHE;
 void KDecimalByteCodec::encode( TQString &Digits, unsigned int Pos, unsigned char Char ) const
 {
   unsigned char C = Char / 100;
-  Digits.tqat(Pos++) = '0'+C;
+  Digits.at(Pos++) = '0'+C;
   Char -= C * 100;
   C = Char / 10;
-  Digits.tqat(Pos++) = '0'+C;
+  Digits.at(Pos++) = '0'+C;
   Char -= C * 10;
-  Digits.tqat(Pos) = '0'+Char;
+  Digits.at(Pos) = '0'+Char;
 }
 
 
@@ -38,15 +38,15 @@ void KDecimalByteCodec::encodeShort( TQString &Digits, unsigned int Pos, unsigne
   unsigned char C;
   if( (C = Char / 100) )
   {
-    Digits.tqat(Pos++) = '0'+C;
+    Digits.at(Pos++) = '0'+C;
     Char -= C * 100;
   }
   if( (C = Char / 10) )
   {
-    Digits.tqat(Pos++) = '0'+C;
+    Digits.at(Pos++) = '0'+C;
     Char -= C * 10;
   }
-  Digits.tqat(Pos) = '0'+Char;
+  Digits.at(Pos) = '0'+Char;
 }
 
 
diff --git a/khexedit/lib/codecs/khexadecimalbytecodec.cpp b/khexedit/lib/codecs/khexadecimalbytecodec.cpp
index 46abdad..596fd24 100644
--- a/khexedit/lib/codecs/khexadecimalbytecodec.cpp
+++ b/khexedit/lib/codecs/khexadecimalbytecodec.cpp
@@ -41,16 +41,16 @@ bool KHexadecimalByteCodec::smallDigits() const { return Digit != BigDigit; }
 
 void KHexadecimalByteCodec::encode( TQString &Digits, unsigned int Pos, unsigned char Char ) const
 {
-  Digits.tqat(Pos++) = Digit[Char>>4];
-  Digits.tqat(Pos) = Digit[Char&0x0F];
+  Digits.at(Pos++) = Digit[Char>>4];
+  Digits.at(Pos) = Digit[Char&0x0F];
 }
 
 void KHexadecimalByteCodec::encodeShort( TQString &Digits, unsigned int Pos, unsigned char Char ) const
 {
   unsigned char C;
   if( (C = (Char>>4)) )
-    Digits.tqat(Pos++) = Digit[C];
-  Digits.tqat(Pos) = Digit[Char&0x0F];
+    Digits.at(Pos++) = Digit[C];
+  Digits.at(Pos) = Digit[Char&0x0F];
 }
 
 
diff --git a/khexedit/lib/codecs/koctalbytecodec.cpp b/khexedit/lib/codecs/koctalbytecodec.cpp
index 7aa156d..44c7952 100644
--- a/khexedit/lib/codecs/koctalbytecodec.cpp
+++ b/khexedit/lib/codecs/koctalbytecodec.cpp
@@ -23,9 +23,9 @@ using namespace KHE;
 
 void KOctalByteCodec::encode( TQString &Digits, unsigned int Pos, unsigned char Char ) const
 {
-  Digits.tqat(Pos++) = '0'+(Char>>6);
-  Digits.tqat(Pos++) = '0'+((Char>>3)&0x07);
-  Digits.tqat(Pos) = '0'+((Char)   &0x07);
+  Digits.at(Pos++) = '0'+(Char>>6);
+  Digits.at(Pos++) = '0'+((Char>>3)&0x07);
+  Digits.at(Pos) = '0'+((Char)   &0x07);
 }
 
 
@@ -33,10 +33,10 @@ void KOctalByteCodec::encodeShort( TQString &Digits, unsigned int Pos, unsigned
 {
   unsigned char C;
   if( (C = (Char>>6)&0x07) )
-    Digits.tqat(Pos++) = '0'+C;
+    Digits.at(Pos++) = '0'+C;
   if( (C = (Char>>3)&0x07) )
-    Digits.tqat(Pos++) = '0'+C;
-  Digits.tqat(Pos) = '0'+((Char)&0x07);
+    Digits.at(Pos++) = '0'+C;
+  Digits.at(Pos) = '0'+((Char)&0x07);
 }
 
 
diff --git a/khexedit/lib/kbufferdrag.cpp b/khexedit/lib/kbufferdrag.cpp
index 3809b61..35fbbca 100644
--- a/khexedit/lib/kbufferdrag.cpp
+++ b/khexedit/lib/kbufferdrag.cpp
@@ -166,7 +166,7 @@ TQByteArray KBufferDrag::encodedData( const char *Format ) const
         { 
           KHEChar B = CharCodec->decode( Data[i] );
 
-          Text.tqat(i) = B.isUndefined() ? KHEChar(UndefinedChar) :
+          Text.at(i) = B.isUndefined() ? KHEChar(UndefinedChar) :
               (!B.isPrint() && B != Tab && B != Return ) ? KHEChar(SubstituteChar) : B;
         }
         // clean up
diff --git a/khexedit/lib/kbufferranges.h b/khexedit/lib/kbufferranges.h
index 6b293b2..ed2cbce 100644
--- a/khexedit/lib/kbufferranges.h
+++ b/khexedit/lib/kbufferranges.h
@@ -28,7 +28,7 @@ namespace KHE
 {
 
 /** a class to control all the ranges like marking and selections
-  * holds also all modified ranges and merges them so a tqrepaint can take its info from here
+  * holds also all modified ranges and merges them so a repaint can take its info from here
   *
   * @author Friedrich W. H.  Kossebau
   */
diff --git a/khexedit/lib/kbytesedit.h b/khexedit/lib/kbytesedit.h
index 915276b..eedf025 100644
--- a/khexedit/lib/kbytesedit.h
+++ b/khexedit/lib/kbytesedit.h
@@ -39,7 +39,7 @@ class KBytesEditPrivate;
   *       possible changes are told to the widget by repaintRange
   *    b) changing data ranges -> data pointer and length might change
   *       changes told by
-  *       * resetData( char *, int size, bool tqrepaint );
+  *       * resetData( char *, int size, bool repaint );
   *       *
   * 2. used as editor
   *    a) static data ranges
@@ -137,7 +137,7 @@ class KHEXEDIT_EXPORT KBytesEdit : public KHexEdit
       */
     void setKeepsMemory( bool KM = true );
 
-    /** tqrepaint the indizes from i1 to i2 */
+    /** repaint the indizes from i1 to i2 */
     void repaintRange( int i1, int i2 );
 
   protected:
diff --git a/khexedit/lib/kcolumnsview.cpp b/khexedit/lib/kcolumnsview.cpp
index 2b0b157..4bb939a 100644
--- a/khexedit/lib/kcolumnsview.cpp
+++ b/khexedit/lib/kcolumnsview.cpp
@@ -167,7 +167,7 @@ void KColumnsView::drawContents( TQPainter *P, int cx, int cy, int cw, int ch )
       if( AffectedLines.isValid() )
       {
         TQPainter Paint;
-        Paint.tqbegin( const_cast<TQPixmap*>(&LineBuffer), this );
+        Paint.begin( const_cast<TQPixmap*>(&LineBuffer), this );
 
         // starting painting with the first line
         KColumn *C = RedrawColumns.first();
@@ -198,7 +198,7 @@ void KColumnsView::drawContents( TQPainter *P, int cx, int cy, int cw, int ch )
             break;
 
           // to avoid flickers we first paint to the linebuffer
-          Paint.tqbegin( TQT_TQPAINTDEVICE(&LineBuffer), this );
+          Paint.begin( TQT_TQPAINTDEVICE(&LineBuffer), this );
 
           KColumn *C = RedrawColumns.first();
           Paint.translate( C->x(), 0 );
diff --git a/khexedit/lib/kcursor.h b/khexedit/lib/kcursor.h
index bb66003..17b4371 100644
--- a/khexedit/lib/kcursor.h
+++ b/khexedit/lib/kcursor.h
@@ -38,7 +38,7 @@ class KCursor
   public:
     /** sets size of the full cursor */
     void setSize( KPixelX Width, KPixelY Height );
-    /** sets the tqshape of the cursor to be drawn */
+    /** sets the shape of the cursor to be drawn */
     void setShape( KPixelX X, KPixelX W );
 
   public: // access
diff --git a/khexedit/lib/kfixedsizebuffer.cpp b/khexedit/lib/kfixedsizebuffer.cpp
index 83fd134..784858c 100644
--- a/khexedit/lib/kfixedsizebuffer.cpp
+++ b/khexedit/lib/kfixedsizebuffer.cpp
@@ -214,7 +214,7 @@ int KFixedSizeBuffer::fill( const char FChar, int FillLength, unsigned int Pos )
 
 int KFixedSizeBuffer::compare( const KDataBuffer &Other, KSection OtherRange, unsigned int Pos )
 {
-  //kdDebug() << TQString("Pos: %1, OtherRange: (%3/%4)" ).tqarg(Pos).tqarg(OtherRange.start()).tqarg(OtherRange.end())
+  //kdDebug() << TQString("Pos: %1, OtherRange: (%3/%4)" ).arg(Pos).arg(OtherRange.start()).arg(OtherRange.end())
   //    << endl;
   // test other values
   if( OtherRange.startsBehind(Other.size()-1) )
@@ -245,14 +245,14 @@ int KFixedSizeBuffer::compare( const KDataBuffer &Other, KSection OtherRange, un
       ValueByLength = -1;
   }
   //kdDebug()
-  //    << TQString( "Range: (%1/%2), OtherRange: (%3/%4)" ).tqarg(Range.start()).tqarg(Range.end()).tqarg(OtherRange.start()).tqarg(OtherRange.end())
+  //    << TQString( "Range: (%1/%2), OtherRange: (%3/%4)" ).arg(Range.start()).arg(Range.end()).arg(OtherRange.start()).arg(OtherRange.end())
   //    << endl;
   int oi = OtherRange.start();
   for( int i=Range.start(); i<=Range.end(); ++i,++oi )
   {
     char OD = Other.datum(oi);
     char D = Data[i];
-    //kdDebug() << TQString("%1==%2").tqarg((int)D).tqarg((int)OD) << endl;
+    //kdDebug() << TQString("%1==%2").arg((int)D).arg((int)OD) << endl;
     if( OD == D )
       continue;
     return OD < D ? 1 : -1;
diff --git a/khexedit/lib/khexedit.cpp b/khexedit/lib/khexedit.cpp
index 1e59d2f..f8fecc9 100644
--- a/khexedit/lib/khexedit.cpp
+++ b/khexedit/lib/khexedit.cpp
@@ -199,7 +199,7 @@ void KHexEdit::setOverwriteMode( bool OM )
   OverWrite = OM;
 
   // affected:
-  // cursor tqshape
+  // cursor shape
   bool ChangeCursor = !( CursorPaused || ValueEditor->isInEditMode() );
   if( ChangeCursor )
     pauseCursor();
@@ -1275,15 +1275,15 @@ void KHexEdit::createCursorPixmaps()
   int Index = BufferCursor->validIndex();
 
   TQPainter Paint;
-  Paint.tqbegin( const_cast<TQPixmap*>(&CursorPixmaps->offPixmap()), this );
+  Paint.begin( const_cast<TQPixmap*>(&CursorPixmaps->offPixmap()), this );
   activeColumn().paintByte( &Paint, Index );
   Paint.end();
 
-  Paint.tqbegin( const_cast<TQPixmap*>(&CursorPixmaps->onPixmap()), this );
+  Paint.begin( const_cast<TQPixmap*>(&CursorPixmaps->onPixmap()), this );
   activeColumn().paintCursor( &Paint, Index );
   Paint.end();
 
-  // calculat the tqshape
+  // calculat the shape
   KPixelX CursorX;
   KPixelX CursorW;
   if( BufferCursor->isBehind() )
@@ -1498,7 +1498,7 @@ void KHexEdit::paintLine( KBufferColumn *C, int Line, KSection Positions )
 
   // to avoid flickers we first paint to the linebuffer
   TQPainter Paint;
-  Paint.tqbegin( &LineBuffer, this );
+  Paint.begin( &LineBuffer, this );
 
   Paint.translate( C->x(), 0 );
   C->paintPositions( &Paint, Line, Positions );
diff --git a/khexedit/lib/kplainbuffer.cpp b/khexedit/lib/kplainbuffer.cpp
index 08874ba..02b9d70 100644
--- a/khexedit/lib/kplainbuffer.cpp
+++ b/khexedit/lib/kplainbuffer.cpp
@@ -72,7 +72,7 @@ int KPlainBuffer::insert( int Pos, const char* D, int Length )
   // check all parameters
   if( Length == 0 )
     return 0;
-  //kdDebug() << TQString("before: Size: %1, RawSize: %2").tqarg(Size).tqarg(RawSize) << endl;
+  //kdDebug() << TQString("before: Size: %1, RawSize: %2").arg(Size).arg(RawSize) << endl;
   // correct for appending
   if( Pos > (int)Size )
     Pos = Size;
@@ -82,7 +82,7 @@ int KPlainBuffer::insert( int Pos, const char* D, int Length )
   // copy new data to its place
   memcpy( &Data[Pos], D, Length );
 
-  //kdDebug() << TQString("after: Size: %1, RawSize: %2").tqarg(Size).tqarg(RawSize) << endl;
+  //kdDebug() << TQString("after: Size: %1, RawSize: %2").arg(Size).arg(RawSize) << endl;
 
   Modified = true;
   return Length;
diff --git a/khexedit/optiondialog.cc b/khexedit/optiondialog.cc
index 8709df4..c631195 100644
--- a/khexedit/optiondialog.cc
+++ b/khexedit/optiondialog.cc
@@ -46,9 +46,9 @@
 #include <tqobjectlist.h>
 static void enableWidget( TQWidget *w, bool state )
 {
-  if( w->tqchildren() )
+  if( w->children() )
   {
-    TQObjectList *l = (TQObjectList*)w->tqchildren(); // silence please
+    TQObjectList *l = (TQObjectList*)w->children(); // silence please
     for( uint i=0; i < l->count(); i++ )
     {
       TQObject *o = l->at(i);
@@ -351,7 +351,7 @@ void COptionDialog::setupColorPage( void )
   modeList.append( i18n("Marked Background") );
   modeList.append( i18n("Marked Text") );
   modeList.append( i18n("Cursor Background") );
-  modeList.append( i18n("Cursor Text (block tqshape)") );
+  modeList.append( i18n("Cursor Text (block shape)") );
   modeList.append( i18n("Bookmark Background") );
   modeList.append( i18n("Bookmark Text") );
   modeList.append( i18n("Separator") );
diff --git a/khexedit/parts/kbytesedit/kbyteseditwidget.h b/khexedit/parts/kbytesedit/kbyteseditwidget.h
index 1f44fbf..5e16bfa 100644
--- a/khexedit/parts/kbytesedit/kbyteseditwidget.h
+++ b/khexedit/parts/kbytesedit/kbyteseditwidget.h
@@ -86,7 +86,7 @@ class KBytesEditWidget : public TQWidget, public KHE::BytesEditInterface,
     virtual bool isOverwriteOnly() const;
     virtual bool isReadOnly() const;
     virtual bool isModified() const;
-    /** tqrepaint the indizes from i1 to i2 */
+    /** repaint the indizes from i1 to i2 */
     virtual void repaintRange( int i1, int i2 );
 
   public: // cursor interface
diff --git a/khexedit/statusbarprogress.cc b/khexedit/statusbarprogress.cc
index 493f002..8ac56bb 100644
--- a/khexedit/statusbarprogress.cc
+++ b/khexedit/statusbarprogress.cc
@@ -212,13 +212,13 @@ int CStatusBarProgress::recalcValue(int range)
 
 void CStatusBarProgress::valueChange()
 {
-  tqrepaint(contentsRect(), FALSE);
+  repaint(contentsRect(), FALSE);
   emit percentageChanged(recalcValue(100));
 }
 
 void CStatusBarProgress::rangeChange()
 {
-  tqrepaint(contentsRect(), FALSE);
+  repaint(contentsRect(), FALSE);
   emit percentageChanged(recalcValue(100));
 }
 
@@ -259,17 +259,17 @@ void CStatusBarProgress::drawText( TQPainter *p )
 
   if( mMsg.isEmpty() == true )
   {
-    s = TQString("%1%").tqarg(recalcValue(100));
+    s = TQString("%1%").arg(recalcValue(100));
   }
   else
   {
     if( mCurPage > 0 )
     {
-      s = i18n("%1... %2 of %3").tqarg(mMsg).tqarg(mCurPage).tqarg(mMaxPage);
+      s = i18n("%1... %2 of %3").arg(mMsg).arg(mCurPage).arg(mMaxPage);
     }
     else
     {
-      s = i18n("%1... %2%").tqarg(mMsg).tqarg(recalcValue(100));
+      s = i18n("%1... %2%").arg(mMsg).arg(recalcValue(100));
     }
   }
 
diff --git a/khexedit/stringdialog.cc b/khexedit/stringdialog.cc
index efd0933..52a845e 100644
--- a/khexedit/stringdialog.cc
+++ b/khexedit/stringdialog.cc
@@ -372,8 +372,8 @@ void CStringDialog::appendListItem( const TQString &str, uint offsetLen )
 
 void CStringDialog::updateListInfo( void )
 {
-  mListSizeLabel->setText( TQString("%1").tqarg(mStringData.count()) );
-  mDisplaySizeLabel->setText( TQString("%1").tqarg(mStringList->childCount()) );
+  mListSizeLabel->setText( TQString("%1").arg(mStringData.count()) );
+  mDisplaySizeLabel->setText( TQString("%1").arg(mStringList->childCount()) );
   setColumnWidth();
 }
 
diff --git a/khexedit/toplevel.cc b/khexedit/toplevel.cc
index d31bb7f..c55e334 100644
--- a/khexedit/toplevel.cc
+++ b/khexedit/toplevel.cc
@@ -391,7 +391,7 @@ void KHexEdit::initialize( bool openFiles )
         maxItems = 1;
     for( unsigned int i = 1 ; i <= maxItems ; i++ )
     {
-        const TQString key = TQString( "File%1" ).tqarg( i );
+        const TQString key = TQString( "File%1" ).arg( i );
         const TQString value = config->readPathEntry( key );
     
         if (!value.isEmpty())
@@ -533,7 +533,7 @@ void KHexEdit::slotFileOpenRecent( const KURL& url )
   else
   {
     // ### TODO: support network transparency
-    KMessageBox::error( this, i18n("Non local recent file: %1").tqarg( url.prettyURL() ) );
+    KMessageBox::error( this, i18n("Non local recent file: %1").arg( url.prettyURL() ) );
   }
 }
 
@@ -788,7 +788,7 @@ void KHexEdit::fileState( SFileState &state )
 {
   if( state.valid == true )
   {
-    statusBar()->changeItem( i18n("Size: %1").tqarg( state.size ), status_Size);
+    statusBar()->changeItem( i18n("Size: %1").arg( state.size ), status_Size);
     statusBar()->changeItem( state.modified ? "!" : "", status_Modified);
 
     if( mIsModified != state.modified )
@@ -922,7 +922,7 @@ void KHexEdit::bookmarkChanged( TQPtrList<SCursorOffset> &list )
   for( SCursorOffset *p=list.first(); p!=0; p=list.next(), i++ )
   {
     offset.sprintf("%04X:%04X", p->offset>>16, p->offset&0x0000FFFF );
-    text = i18n("Offset: %1").tqarg(offset);
+    text = i18n("Offset: %1").arg(offset);
     KAction *action = new KAction(text, 0, mAction.bookmarkMapper, TQT_SLOT(map()), TQT_TQOBJECT(this), text.latin1());
     int key = acceleratorNumKey( i );
     if( key > 0 )
@@ -1021,7 +1021,7 @@ void KHexEdit::encodingChanged( const SEncodeState &encodeState )
 
   if( mSelectionSize == 0 )
   {
-    statusBar()->changeItem( i18n("Encoding: %1").tqarg(encodeState.name),
+    statusBar()->changeItem( i18n("Encoding: %1").arg(encodeState.name),
 			     status_Selection );
   }
 }
@@ -1186,7 +1186,7 @@ void KHexEdit::setSelectionText( uint selectionOffset, uint selectionSize )
   else
   {
     statusBar()->changeItem(
-      i18n("Encoding: %1").tqarg(hexView()->encoding().name), status_Selection);
+      i18n("Encoding: %1").arg(hexView()->encoding().name), status_Selection);
   }
 }
 
diff --git a/khexedit/toplevel.h b/khexedit/toplevel.h
index 5e72dee..9f52418 100644
--- a/khexedit/toplevel.h
+++ b/khexedit/toplevel.h
@@ -249,7 +249,7 @@ protected:
 inline void KHexEdit::addStartupFile( const TQString &fileName )
 {
   mStartupFileList.prepend( fileName );
-  mStartupOffsetList.prepend( TQString("%1").tqarg(mStartupOffset,0,16) );
+  mStartupOffsetList.prepend( TQString("%1").arg(mStartupOffset,0,16) );
   mStartupOffset = 0;
 }
 
diff --git a/khexedit/hexviewwidget.cc b/khexedit/hexviewwidget.cc
index 0ac3ab8..eb13d18 100644
--- a/khexedit/hexviewwidget.cc
+++ b/khexedit/hexviewwidget.cc
@@ -233,7 +233,7 @@ CHexViewWidget::CHexViewWidget( TQWidget *parent, const char *name,
   setStartY(0);
 
   setAcceptDrops(true);
-  setDropHighlight(false); // Init state + frame tqshape
+  setDropHighlight(false); // Init state + frame shape
   setBackgroundColor( mHexBuffer->backgroundColor() );
 }
 
@@ -459,7 +459,7 @@ void CHexViewWidget::filter( SFilterControl &fc )
   int errCode = mHexBuffer->filter( fc );
   if( errCode == Err_Success )
   {
-    tqrepaint();
+    repaint();
     emit dataChanged();
     emit cursorChanged( mHexBuffer->cursorState() );
   }
@@ -752,7 +752,7 @@ void CHexViewWidget::setColor( const SDisplayColor &color,
   mHexBuffer->setColor( mColor );
   if( updateDisplay == true )
   {
-    tqrepaint();
+    repaint();
   }
 }
 
@@ -796,7 +796,7 @@ int CHexViewWidget::setEncoding( CConversion::EMode mode, CProgress &p )
   int errCode = mHexBuffer->setEncoding( mode, p );
   if( errCode == Err_Success )
   {
-    tqrepaint();
+    repaint();
     emit cursorChanged( mHexBuffer->cursorState() );
     emit encodingChanged( mHexBuffer->encoding() );
   }
@@ -1099,7 +1099,7 @@ int CHexViewWidget::bookmarkMenu( const TQString &title )
     if( p == 0 ) { continue; }
 
     text.sprintf("%04X:%04X", p->offset>>16, p->offset&0x0000FFFF );
-    text.prepend( TQString("[%1] %2: ").tqarg(i+1).tqarg(i18n("Offset")) );
+    text.prepend( TQString("[%1] %2: ").arg(i+1).arg(i18n("Offset")) );
     popup->insertItem( text, i );
   }
 
@@ -1379,7 +1379,7 @@ void CHexViewWidget::drawFrame( TQPainter *p )
   // accepts a drop. The setPalette() function causes quite a bit of flicker
   // in the scrollbars (even when PropagationMode is NoChildren), so I
   // draw the frame manually when it can accept a drop. Note that the
-  // code below is for the frame tqshape "TQFrame::WinPanel|TQFrame::Plain"
+  // code below is for the frame shape "TQFrame::WinPanel|TQFrame::Plain"
   //
   if( mDropHighlight == true )
   {
@@ -1860,7 +1860,7 @@ void CHexViewWidget::setCursorPosition(int x, int y, bool init, bool cellLevel)
 void CHexViewWidget::redrawInterval( uint startOffset, uint stopOffset )
 {
   //
   // Can be improved, I tqrepaint the entire line even if the offsets
   // only specify one byte.
   //
   uint lineStart = mHexBuffer->calculateLine( startOffset );
@@ -2270,7 +2270,7 @@ void CHexViewWidget::setDropHighlight( bool dropHighlight )
     //
     // 2000-01-10 Espen Sand
     // Highlight. I have reimplemented TQFrame::drawFrame(TQPainter *)
-    // to support a custom frame color. I assume the frame tqshape is
+    // to support a custom frame color. I assume the frame shape is
     // "TQFrame::WinPanel|TQFrame::Plain" in that function.
     //
     setFrameStyle( TQFrame::WinPanel|TQFrame::Plain );
@@ -1860,7 +1860,7 @@ void CHexViewWidget::setCursorPosition(int x, int y, bool init, bool cellLevel)
 {
   //
-  // Can be improved, I tqrepaint the entire line even if the offsets
+  // Can be improved, I repaint the entire line even if the offsets
   // only specify one byte.
   //
-- 
cgit v1.2.1